@@ -1,4 +1,5 @@
 from argparse import ArgumentParser
+import colorama
 
 from .__put_cmd import put_cmd_args
 from .__init_cmd import init_cmd_args
@@ -6,6 +7,8 @@ from .__utils import check_update_required
 from .._version import __version__
 
 def main():
+    colorama.init()
+
     check_update_required(__version__)
 
     parser = ArgumentParser(prog='ts-sdk')
