@@ -5,13 +5,26 @@ from pathlib import Path
 import zipfile
 import argparse
 import re
-import sys
-from time import sleep, time
+from time import sleep
 
 from ids_validator.ids_validator import validate_ids
+from loguru import logger
+from ts_sdk.cli.__api import TsApi
+from ts_sdk.cli.__utils import zipdir
+from ts_sdk.cli.put_cmd_helpers.upload_validator import UploadValidator, bytes_as_human_readable_string
 
-from .__api import TsApi
-from .__utils import sizeof_fmt, zipdir
+
+DEFAULT_EXCLUDE_FOLDERS = [
+    '.git',
+    '.venv',
+    'example-input',
+    'example-output',
+    '_tests_',
+    '__tests__',
+    '__test__',
+    'example-files',
+    'raw_data',
+]
 
 
 def put_cmd_args(parser: argparse.ArgumentParser):
@@ -23,6 +36,12 @@ def put_cmd_args(parser: argparse.ArgumentParser):
     parser.add_argument('version', type=__version_type)
     parser.add_argument('folder', type=__folder_type,
                         help='path to folder to be uploaded')
+    parser.add_argument(
+        '--exclude-folders',
+        action='store_true',
+        default=True,
+        help=f"Whether to exclude the following set of folders: {', '.join(DEFAULT_EXCLUDE_FOLDERS)}"
+        )
     parser.add_argument(
         '--force', '-f', action='store_true',
         help='force overwrite of an existing artifact'
@@ -110,6 +129,10 @@ def __validate_ids(args):
     )
 
 
+class PutCmdError(Exception):
+    """Raised whenever the `ts-sdk put` command encounters an error."""
+
+
 def __cmd(args):
     __ensure_args(args)
     print('Config:')
@@ -129,14 +152,22 @@ def __cmd(args):
 
     ts_api = TsApi(**args.__dict__)
 
-    print('Compressing...', flush=True)
+    logger.info('Compressing...', flush=True)
     zip_buffer = io.BytesIO()
     zipf = zipfile.ZipFile(zip_buffer, 'a', zipfile.ZIP_DEFLATED, False)
-    zipdir(args.folder, zipf)
+    exclude_folders = []
+    if args.exclude_folders:
+        exclude_folders = DEFAULT_EXCLUDE_FOLDERS
+    zipdir(args.folder, zipf, exclude_folders)
     zipf.close()
     zip_bytes = zip_buffer.getvalue()
 
-    print(f'Uploading {sizeof_fmt(len(zip_bytes))}...', flush=True)
+    upload_size_checker = UploadValidator()
+    maybe_error_messages = upload_size_checker.validate(zip_bytes)
+    if len(maybe_error_messages) > 0:
+        raise PutCmdError(*maybe_error_messages)
+
+    logger.info(f'Uploading {bytes_as_human_readable_string(len(zip_bytes))}...')
 
     r = ts_api.upload_artifact(args, zip_bytes)
 
