@@ -260,12 +260,17 @@ class Context:
         """Returns the value of the secret.
         If secret is missing, empty string or throws error, depending on the second argument.
         """
+
         return get_secret_config_value(self._obj, secret_name, silent_on_error)
 
     def resolve_secret(self, secret) -> str:
         """Returns the value of the secret.
         """
+
         if type(secret) is dict and 'ssm' in secret:
+            pipeline_config = self._obj.get('pipelineConfig')
+            if f'_resolved_:{secret["ssm"]}' in pipeline_config:
+                return pipeline_config.get(f'_resolved_:{secret["ssm"]}')
             key = re.sub(r"^/[^/]*/[^/]*/org-secrets/", '', secret['ssm'])
             key = re.sub(r"[^a-z0-9]+", '_', key, flags=re.IGNORECASE)
             secret_value = os.environ.get('SECRET_' + key)
@@ -420,6 +425,9 @@ def get_secret_config_value(context_from_arg, secret_name, silent_on_error=True)
     secret_short_name = secret_name
     secret_full_key = 'ts_secret_name_' + secret_name
 
+  if f'_resolved_:{secret_short_name}' in pipeline_config:
+      return pipeline_config.get(f'_resolved_:{secret_short_name}')
+
   if not secret_full_key in pipeline_config.keys() or pipeline_config.get(secret_full_key) is None:
     if silent_on_error:
       Context.log.log(f'Secret {secret_full_key} not found in the workflow config.')
