@@ -1,4 +1,5 @@
 # These should be kept in sync with S3MetadataFields.js in ts-lib-shared-schema
+# https://github.com/tetrascience/ts-lib-shared-schema/blob/master/src/S3MetadataFields.js
 FIELDS = {
     'VERSION': 'ts_version',
     'INTEGRATION_TYPE': 'ts_integration_type',
@@ -35,5 +36,9 @@ FIELDS = {
     'PIPELINE_WORKFLOW_ID': 'ts_workflow_id',
     'PIPELINE_HISTORY': 'ts_pipeline_history',
 
-    'TRACE_ID': 'ts_trace_id'
+    'TRACE_ID': 'ts_trace_id',
+
+    'CONTENT_CREATED_FROM_FILE_ID' : 'ts_content_created_from_file_id',
+
+    'DO_NOT_INHERIT_LABELS': 'ts_do_not_inherit_labels'
 }
